@@ -39,7 +39,7 @@
 # * Internet router from Cisco Systems, and became the first satellite
 # * to run IPv6 and the Delay-Tolerant Networking 'Bundle Protocol'.
 #
-# $Id: dmc.tcl,v 1.17 2012/01/20 06:20:54 lloydwood Exp $
+# $Id: dmc.tcl,v 1.18 2015/01/15 23:03:13 lloydwood Exp $
 
 # sun-synchronous, so turn on sunlight
 upvar #0 sun_flag sun_flag
@@ -68,7 +68,7 @@ set coverage_angle 66.4
 # set coverage_angle_flag 1
 # puts stderr "\n\nSaVi: half-cone coverage angle of $coverage_angle deg shows extent of DMC imaging swath."
 
-puts stderr "SaVi: imaging swath shown. Set mask angle to zero for limits of communications connectivity."
+puts stderr "\nSaVi: imaging swath shown. Set mask angle to zero for limits of communications connectivity."
 
 set SATS_PER_PLANE 4
 
