@@ -22,7 +22,7 @@
 # * Not built. Ellipsat Inc. announced an alliance with ICO/Teledesic
 # * in March 2001.
 # *
-# $Id: ellipso.tcl,v 1.10 2016/01/09 23:04:34 lloydwood Exp $
+# $Id: ellipso.tcl,v 1.11 2016/05/05 08:04:44 lloydwood Exp $
 
 # to ensure overlapping coverage in the northern hemisphere
 set coverage_angle 25
@@ -80,12 +80,14 @@ set inc 0
 set Omega 0.0
 set omega 0.0
 
+set SATS_PER_PLANE 6
+
 # compute period of orbit
 set T_per [expr 2 * $PI * pow($a,1.5) / sqrt($MU)]
 
 satellites GV_BEGIN
-for {set i 0} {$i < 6} {incr i} {
-	set T [expr $T_per*$i/6]
+for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
+	set T [expr $T_per*$i/$SATS_PER_PLANE]
 	satellites LOAD $a $e $inc $Omega $omega $T "Ellipso-Concordia ($i)"
 }
 satellites GV_END
