@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2016 by Lloyd Wood.
+ *  Also Copyright (c) 2017 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -22,7 +22,7 @@
  *
  * Coverage visualization routines.
  *
- * $Id: coverage_vis.c,v 1.136 2016/03/16 01:26:48 lloydwood Exp $
+ * $Id: coverage_vis.c,v 1.138 2017/06/28 11:09:50 lloydwood Exp $
  */
 
 #include <math.h>
@@ -81,8 +81,6 @@ static int gzip_compress2(Bytef *dest, uLongf *destLen,
                         const Bytef *source, uLong sourceLen,
                         int level);
 static void write_image_to_stream_compressed();
-static void write_image_as_ppm_gz(gzFile *f);
-static void write_image_to_file_gz(char *name);
 
 static void * image_compress_scratch = NULL;
 #endif /* NO_ZLIB */
@@ -536,47 +534,6 @@ write_image_to_stream_compressed(void)
    gv_send("\n} } )\n");
    gv_end();
 }
-
-/* function requires zlib */
-static void
-write_image_as_ppm_gz(gzFile *f)
-{
-  unsigned int w, h, length, gzlength;
-  unsigned char *p;
-
-  /* this was grid g->width, but for temporary convenience... */
-  w = Image_Width;
-  h = Image_Height;
-
-  /*
-   * Write header file describing grid
-   */
-  gzprintf(f,"P6\n%i %i\n255\n", w, h);
-
-  length = w * h * PIXELSIZE * sizeof(unsigned char);
-  p = image->pixelPtr;
-  gzlength = gzwrite(f, p, length);
-  if (debug) {
-    fprintf(stderr, "Compressed coverage image of %i bytes to disk; wrote %i bytes.\n", length, gzlength);
-  }
-}
-
-/* function requires zlib */
-static void
-write_image_to_file_gz(char * name)
-{
-  gzFile *f;
-
-  if (NULL == (f = gzopen(name, "w"))) {
-    fprintf(stderr,"\nSaVi: unable to save compressed coverage map to %s", name);
-    return;
-  }
-
-  gzsetparams(name, Z_BEST_COMPRESSION, Z_RLE); /* Z_RLE for PNG-style data */
-  write_image_as_ppm_gz(f);
-
-  gzclose(f);
-}
 #endif /* NO_ZLIB */
 
 static void
