@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2016 by Lloyd Wood.
+ *  Also Copyright (c) 2017 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * stats_utils.c
  *
- * $Id: stats_utils.c,v 1.44 2016/01/09 04:21:17 lloydwood Exp $
+ * $Id: stats_utils.c,v 1.46 2017/06/07 21:34:22 lloydwood Exp $
  */
 
 #include <stdio.h>
@@ -165,8 +165,13 @@ fill_grid(const Satellite_list SL, int current_projection, int fp_angle_type,
   for (sl = SL; NULL != sl; sl = sl->next) {
     if (sl->s->can_display_coverage) {
       a = sl->s->x_S.r - pcb->radius;
-      if (a <= min_transmit_altitude) {
-         continue;
+      if (!sunlight && ((min_transmit_altitude > 0)||(max_transmit_altitude > 0))) {
+        if (a <= min_transmit_altitude) {
+           continue;
+        }
+        if (a >= max_transmit_altitude) {
+           continue;
+        }
       }
       footprint_circle(&c, &u, &v, fp_angle_type, angle,
 		       &(sl->s->x_C), pcb);
