@@ -6,7 +6,7 @@
  *          Robert Thurman.
  *
  *  Copyright (c) 1997 by The Geometry Center.
- *  Also Copyright (c) 2016 by Lloyd Wood.
+ *  Also Copyright (c) 2017 by Lloyd Wood.
  *
  *  This file is part of SaVi.  SaVi is free software;
  *  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
  *
  * tcl_utils.c
  *
- * $Id: tcl_utils.c,v 1.43 2016/02/09 05:11:49 lloydwood Exp $
+ * $Id: tcl_utils.c,v 1.45 2017/06/26 04:33:07 lloydwood Exp $
  */
 
 #include "constants.h"
@@ -87,12 +87,20 @@ tk_init(Tcl_Interp * interpreter)
 
 #if ( (TK_MAJOR_VERSION > 4) || ( (TK_MAJOR_VERSION == 4) && (TK_MINOR_VERSION > 0)) )
   if (!(mainWindow = Tk_CreateWindow(interpreter, screenName, baseName, className))) {
+#  if (TK_MAJOR_VERSION >= 8)
+    error_format("tk_init: Can't create main wainWindow: %s", Tcl_GetStringResult(interpreter));
+#  else
     error_format("tk_init: Can't create main wainWindow: %s", interpreter->result);
+#  endif
     return FALSE;
   }
 #else
   if (!(mainWindow = Tk_CreateMainWindow(interpreter, screenName, baseName, className))) {
+#  if (TK_MAJOR_VERSION >= 8)
+    error_format("tk_init: Can't create main wainWindow: %s", Tcl_GetStringResult(interpreter));
+#  else
     error_format("tk_init: Can't create main wainWindow: %s", interpreter->result);
+#  endif
     return FALSE;
   }
 #endif
@@ -297,7 +305,11 @@ unsigned int
 tcl_script(char script[])
 {
   if (Tcl_GlobalEval(interp, script) == TCL_ERROR) {
+#if (TK_MAJOR_VERSION >= 8)
+    error_format("tcl_error: %s", Tcl_GetStringResult(interp));
+#else
     error_format("tcl_error: %s", interp->result);
+#endif
     return FALSE;
   }
   return TRUE;
