@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # coverage.tcl
 #
-# $Id: coverage.tcl,v 1.174 2016/03/29 01:53:57 lloydwood Exp $
+# $Id: coverage.tcl,v 1.176 2017/07/02 11:07:11 lloydwood Exp $
 
 # Note: IM_W and IM_H are linked to C variables for the image size
 
@@ -821,14 +821,14 @@ proc coverage(blend_colors) {} {
 }
 
 proc coverage(save_colors) {} {
-    global DIV DEC
-    global NUM_COLORS
+    global DIV DEC NUM_COLORS
+    global user_file_dir
 
     set types {
         {"SaVi coverage color shades"  {.shades} }
     }
 
-    set filename [tk_getSaveFile -filetypes $types \
+    set filename [tk_getSaveFile -initialdir "$user_file_dir" -filetypes $types \
 	          -title "SaVi: save coverage color shades" ]
 
     if {"$filename" == ""} return
@@ -859,12 +859,13 @@ proc coverage(save_colors) {} {
 }
 
 proc coverage(load_colors) {} {
+   global user_file_dir
 
     set types {
         {"SaVi coverage color shades"  {.shades} }
     }
 
-    set filename [tk_getOpenFile -filetypes $types \
+    set filename [tk_getOpenFile -initialdir "$user_file_dir" -filetypes $types \
 	          -parent .main -title "SaVi: load coverage color shades" ]
 
     if {"$filename" == ""} return
@@ -953,6 +954,7 @@ proc coverage(save_map_handler) {filename} {
 }
 
 proc coverage(save_map) {} {
+    global user_file_dir
 
     # {"SaVi coverage map (png)" {.png} }
     # gives two-color images in 8.6 only, doesn't work in 8.5,
@@ -965,7 +967,7 @@ proc coverage(save_map) {} {
 	{"SaVi coverage map (gzipped)" {.ppm.gz} } \
     }
 
-    set filename [tk_getSaveFile -filetypes $types \
+    set filename [tk_getSaveFile -initialdir "$user_file_dir" -filetypes $types \
 	          -parent .coverage -title "SaVi: save coverage map" ]
 
     if {"$filename" == ""} return
