@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # fisheye.tcl
 #
-# $Id: fisheye.tcl,v 1.69 2016/05/30 11:22:25 lloydwood Exp $
+# $Id: fisheye.tcl,v 1.71 2017/07/02 11:07:11 lloydwood Exp $
 
 proc fisheye(init) {} {
     global fisheye_flag fisheye_reverse_view_flag fisheye_names_flag fisheye_numbers_flag \
@@ -437,12 +437,13 @@ proc fisheye(set_location) {lat_degrees lat_minutes long_degrees long_minutes lo
 }
 
 proc fisheye(save) {} {
+    global user_file_dir
 
     set types {
         {"Postscript files"  {.ps} }
     }
 
-    set filename [tk_getSaveFile -filetypes $types \
+    set filename [tk_getSaveFile -initialdir "$user_file_dir" -filetypes $types \
 	          -title "SaVi: save fisheye as Postscript" ]
 
     if {"$filename" == ""} return
