@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # init.tcl
 #
-# $Id: init.tcl,v 1.93 2016/02/12 06:38:31 lloydwood Exp $
+# $Id: init.tcl,v 1.96 2017/07/02 11:07:11 lloydwood Exp $
 
 proc geomview_init {} {
     global satellites_flag box_sat_flag planes_sat_flag fancy_sat_flag \
@@ -84,7 +84,7 @@ proc geomview_init {} {
 proc app_init {} {
     global TITLE FONT COLOR NUM_COLORS NUM_COLORS_PREV PLATFORM Projection
     global first_filename last_filename source_comments comments_text comments_file details_source
-    global helpfile_text helpfile_name geomview_module
+    global user_file_dir helpfile_text helpfile_name geomview_module
     global realtime_flag sun_flag playbar delta_t splash_about rendering_size
     global plane_flag
     global modifier modifier_indicator
@@ -112,7 +112,7 @@ proc app_init {} {
       set modifier "Command"
       set modifier_indicator "Command"
       set PLATFORM 1
-    } elseif {[string equal [tk windowingsystem] win32]||[file exists /cygdrive]} {
+    } elseif {[string equal [tk windowingsystem] win32]||[file exists "/proc/cygdrive"]} {
       # Tcl on Windows - grey to match XP. Vary to suit interface.
       set COLOR(bg) #d4d0c8
       set COLOR(abg) #bbb
@@ -147,6 +147,9 @@ proc app_init {} {
     tk_setPalette background $COLOR(bg) \
 	 activeBackground $COLOR(abg) selectBackground $COLOR(abg)
 
+    # set directory for saving files to user's home directory
+    set user_file_dir "~/"
+
     # close the default toplevel window
     wm withdraw .
 
