@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # load.tcl
 #
-# $Id: load.tcl,v 1.20 2016/01/09 04:21:17 lloydwood Exp $
+# $Id: load.tcl,v 1.22 2017/07/02 11:07:11 lloydwood Exp $
 
 proc load(build) {} {
 
@@ -29,7 +29,7 @@ proc load(build) {} {
         {"Two-line element sets" {.tle} }
     }
 
-    set filename [tk_getOpenFile -filetypes $types \
+    set filename [tk_getOpenFile -initialdir "data/" -filetypes $types \
 	          -parent .main -title "SaVi: load satellites" ]
 
     if {"$filename" == ""} return
