@@ -6,7 +6,7 @@
 #          Robert Thurman.
 #
 #  Copyright (c) 1997 by The Geometry Center.
-#  Also Copyright (c) 2016 by Lloyd Wood.
+#  Also Copyright (c) 2017 by Lloyd Wood.
 #
 #  This file is part of SaVi.  SaVi is free software;
 #  you can redistribute it and/or modify it only under
@@ -20,7 +20,7 @@
 #
 # main.tcl
 #
-# $Id: main.tcl,v 1.162 2016/09/03 06:49:39 lloydwood Exp $
+# $Id: main.tcl,v 1.166 2017/01/02 11:30:45 lloydwood Exp $
 
 proc main(build) {} {
     global main_name COLOR FONT TITLE geomview_module last_filename PLATFORM
@@ -217,6 +217,8 @@ proc main(constellations_menu) {submenu} {
         {"Orblink" "main(constellation) orblink.tcl"} \
         {"LEq0" "main(constellation) leqo.tcl"} \
         {} \
+        {"ViaSat NGSO" "main(constellation) viasat-ngso.tcl"} \
+	{"O3b full global coverage" "main(constellation) o3b-networks-full.tcl"} \
 	{"LeoSat (108)" "main(constellation) leosat.tcl"} \
 	{"OneWeb (720)" "main(constellation) oneweb.tcl"} \
 	{} \
